@@ -1,5 +1,5 @@
 import re
-
+from typogrify.packages.titlecase import titlecase  # NOQA
 
 class TypogrifyError(Exception):
     """ A base error class so we can catch or scilence typogrify's errors in templates """
@@ -29,8 +29,8 @@ def process_ignores(text, ignore_tags=None):
         ignore_tags = []
 
     ignore_tags = ignore_tags + ['pre', 'code']  # default tags
-    ignoreregex = r'<(%s).*?>.*?</(\1)>' % '|'.join(ignore_tags)
-    ignore_finder = re.compile(ignoreregex, re.IGNORECASE | re.DOTALL)
+    ignore_regex = r'<(%s)(?:\s.*?)?>.*?</(\1)>' % '|'.join(ignore_tags)
+    ignore_finder = re.compile(ignore_regex, re.IGNORECASE | re.DOTALL)
 
     for section in ignore_finder.finditer(text):
         start, end = section.span()
@@ -45,7 +45,7 @@ def process_ignores(text, ignore_tags=None):
 
         position = end
 
-    # match the rest of the text if necessary 
+    # match the rest of the text if necessary
     # (this could in fact be the entire string)
     if position < len(text):
         sections.append((text[position:len(text)], True))
@@ -223,22 +223,6 @@ def smartypants(text):
         return output
 
 
-def titlecase(text):
-    """Support for titlecase.py's titlecasing
-
-    >>> titlecase("this V that")
-    'This v That'
-
-    >>> titlecase("this is just an example.com")
-    'This Is Just an example.com'
-    """
-    try:
-        import titlecase
-    except ImportError:
-        raise TypogrifyError("Error in {% titlecase %} filter: The titlecase.py library isn't installed.")
-    else:
-        return titlecase.titlecase(text)
-
 def widont(text):
     """Replaces the space between the last two words in a string with ``&nbsp;``
     Works in these block tags ``(h1-h6, p, li, dd, dt)`` and also accounts for
